summaryrefslogtreecommitdiffstats
path: root/kdesktop
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-10 17:43:13 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-10 17:43:13 -0600
commit60a25a0fe53314833e60161c57e7f19290f70c63 (patch)
treef1d27e1a53b89a124f2d8883220bf22651863c8e /kdesktop
parentdc60162d6a68fac0f7f5eb381f40e0c878072673 (diff)
downloadtdebase-60a25a0fe53314833e60161c57e7f19290f70c63.tar.gz
tdebase-60a25a0fe53314833e60161c57e7f19290f70c63.zip
Fix icons not showing up on desktop and popup menu entries not appearing
Diffstat (limited to 'kdesktop')
-rw-r--r--kdesktop/kdiconview.cc18
1 files changed, 9 insertions, 9 deletions
diff --git a/kdesktop/kdiconview.cc b/kdesktop/kdiconview.cc
index 0e439e880..e2f1c80a0 100644
--- a/kdesktop/kdiconview.cc
+++ b/kdesktop/kdiconview.cc
@@ -1,4 +1,4 @@
/* This file is part of the KDE project
Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
Copyright (C) 2000, 2001 David Faure <faure@kde.org>
@@ -835,12 +835,12 @@ bool KDIconView::deleteGlobalDesktopFiles()
// Ignore these special files
// Name URL Type OnlyShowIn
- // My Documents kxdglauncher --xdgname DOCUMENTS Application KDE;
- // My Computer media:/ Link KDE;
- // My Network Places remote:/ Link KDE;
- // Printers [exec] kjobviewer --all --show %i %m Application KDE;
- // Trash trash:/ Link KDE;
- // Web Browser kfmclient openBrowser %u Application KDE;
+ // My Documents kxdglauncher --xdgname DOCUMENTS Application TDE;
+ // My Computer media:/ Link TDE;
+ // My Network Places remote:/ Link TDE;
+ // Printers [exec] kjobviewer --all --show %i %m Application TDE;
+ // Trash trash:/ Link TDE;
+ // Web Browser kfmclient openBrowser %u Application TDE;
if ( isDesktopFile(fItem) ) {
KSimpleConfig cfg( fItem->url().path(), true );
@@ -1009,12 +1009,12 @@ bool KDIconView::makeFriendlyText( KFileIVI *fileIVI )
TQStringList tmpList;
if (cfg.hasKey("OnlyShowIn"))
{
- if (!cfg.readListEntry("OnlyShowIn", ';').contains("KDE"))
+ if (!cfg.readListEntry("OnlyShowIn", ';').contains("TDE"))
return false;
}
if (cfg.hasKey("NotShowIn"))
{
- if (cfg.readListEntry("NotShowIn", ';').contains("KDE"))
+ if (cfg.readListEntry("NotShowIn", ';').contains("TDE"))
return false;
}
if (cfg.hasKey("TryExec"))
@@ -1,4 +1,4 @@
-/* This file is part of the KDE project
+/* This file is part of the TDE project
Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
Copyright (C) 2000, 2001 David Faure <faure@kde.org>